[![PyPI](https://img.shields.io/pypi/v/ztffields.svg?style=flat-square)](https://pypi.python.org/pypi/ztffields)
[![Documentation Status](https://readthedocs.org/projects/ztffields/badge/?version=latest)](https://ztffields.readthedocs.io/en/latest/?badge=latest)

# ztffields
Tools for ZTF Fields. This is a stand-alone extraction from ztfquery.fields

See [documentation on readthedoc](https://ztffields.readthedocs.io/en/latest/)
